tui

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 16, 2025 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ListItem

type ListItem struct {
	// contains filtered or unexported fields
}

ListItem represents a single renderable line in the TUI list.

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model represents the state of the TUI application.

func InitialModel

func InitialModel(filePath string, pd *parser.ParsedData, w *watcher.Watcher) Model

InitialModel creates the initial model for the Bubble Tea program.

func (Model) Init

func (m Model) Init() tea.Cmd

Init is the first command ran by the Bubble Tea program.

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (Model) View

func (m Model) View() string

View renders the TUI based on the model state.

type Styles

type Styles struct {
	NormalLine      lipgloss.Style
	FocusedLine     lipgloss.Style
	DisabledLine    lipgloss.Style
	EmptyValueStyle lipgloss.Style // Style for <empty> placeholder
	SelectedIcon    lipgloss.Style
	KeyStyle        lipgloss.Style // Style for variable keys
	HeaderTitle     lipgloss.Style
	HeaderFileInfo  lipgloss.Style
	Header          lipgloss.Style
	Footer          lipgloss.Style
	ModifiedStatus  lipgloss.Style
	StatusMessage   lipgloss.Style
	ErrorMessage    lipgloss.Style
	PromptStyle     lipgloss.Style
}

Styles defines the lipgloss styles used in the TUI.

func DefaultStyles

func DefaultStyles() Styles

DefaultStyles creates a default set of styles.

func NatureStyles

func NatureStyles() Styles

NatureStyles creates an alternative set of styles based on natural tones.

Jump to