Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FileChangedMsg ¶
type FileChangedMsg struct{}
FileChangedMsg is sent when the watched file is modified.
type Watcher ¶
type Watcher struct {
Events chan tea.Msg // Channel to send messages back to Bubble Tea
Errors chan error // Channel to send errors (raw errors)
// contains filtered or unexported fields
}
Watcher manages the file system watcher.
func (*Watcher) Start ¶
Start begins watching the specified file. It runs in a goroutine and sends events/errors on the respective channels.
func (*Watcher) WatchFileCmd ¶
WatchFileCmd returns a command that listens for watcher events.
type WatcherErrMsg ¶
type WatcherErrMsg struct {
// contains filtered or unexported fields
}
WatcherErrMsg is sent when the watcher encounters an error.
func (WatcherErrMsg) Error ¶
func (e WatcherErrMsg) Error() string
Click to show internal directories.
Click to hide internal directories.